You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by lo...@apache.org on 2011/08/09 17:49:28 UTC

svn commit: r1155411 - /myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java

Author: lofwyr
Date: Tue Aug  9 15:49:27 2011
New Revision: 1155411

URL: http://svn.apache.org/viewvc?rev=1155411&view=rev
Log:
spelling

Modified:
    myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java

Modified: myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java?rev=1155411&r1=1155410&r2=1155411&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java (original)
+++ myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/TreeNodeTagDeclaration.java Tue Aug  9 15:49:27 2011
@@ -32,7 +32,7 @@ import org.apache.myfaces.tobago.interna
 
 /**
  * Creates a tree node. This component represents a single node inside a tree structure.
- * For interating over tree node use tc:treeData.
+ * For iterating over tree node use tc:treeData.
  */
 @SuppressWarnings("ALL")
 @Tag(name = "treeNode")
@@ -80,13 +80,12 @@ public interface
   void setTreeExpansionListener(String treeExpansionListener);
 
   /**
    * Method binding representing a expansionListener method that ....
    */
-/*
   @TagAttribute
   @UIComponentTagAttribute(type = {},
       expression = DynamicExpression.METHOD_BINDING_REQUIRED,
-      methodSignature = "org.apache.myfaces.tobago.event.TreeSelectionEvent")
-  void setTreeSelectionListener(String treeSelectionListener);
-*/
+      methodSignature = "org.apache.myfaces.tobago.event.TreeMarkedEvent")
+  void setTreeMarkedListener(String treeMarkedListener);
+
 }
@@ -80,13 +80,12 @@ public interface
 
   /**
-   * Method binding representing a expansionListener method that ....
+   * Method binding representing a markedListener method that ....
    */